aboutsummaryrefslogtreecommitdiffstats
path: root/examples/declarative/extending/chapter1-basics/basics.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/declarative/extending/chapter1-basics/basics.py')
-rw-r--r--examples/declarative/extending/chapter1-basics/basics.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/declarative/extending/chapter1-basics/basics.py b/examples/declarative/extending/chapter1-basics/basics.py
index a604a05bc..c14669908 100644
--- a/examples/declarative/extending/chapter1-basics/basics.py
+++ b/examples/declarative/extending/chapter1-basics/basics.py
@@ -39,15 +39,15 @@
##
#############################################################################
"""PySide2 port of the qml/tutorials/extending-qml/chapter1-basics example from Qt v5.x"""
import os
import sys
-from PySide2.QtCore import Property, Signal, QUrl
-from PySide2.QtGui import QGuiApplication, QPen, QPainter, QColor
-from PySide2.QtQml import qmlRegisterType
-from PySide2.QtQuick import QQuickPaintedItem, QQuickView
+from PySide6.QtCore import Property, Signal, QUrl
+from PySide6.QtGui import QGuiApplication, QPen, QPainter, QColor
+from PySide6.QtQml import qmlRegisterType
+from PySide6.QtQuick import QQuickPaintedItem, QQuickView
class PieChart (QQuickPaintedItem):
def __init__(self, parent = None):
@@ -39,15 +39,15 @@
##
#############################################################################
-"""PySide2 port of the qml/tutorials/extending-qml/chapter1-basics example from Qt v5.x"""
+"""PySide6 port of the qml/tutorials/extending-qml/chapter1-basics example from Qt v5.x"""
import os
import sys